@@ -12,10 +12,18 @@ from .core import (
 from .deprecation import AltairDeprecationWarning, deprecated, deprecated_warn
 from .html import spec_to_html
 from .plugin_registry import PluginRegistry
-from .schemapi import Optional, SchemaBase, SchemaLike, Undefined, is_undefined
+from .schemapi import (
+    VERSIONS,
+    Optional,
+    SchemaBase,
+    SchemaLike,
+    Undefined,
+    is_undefined,
+)
 
 __all__ = (
     "SHORTHAND_KEYS",
+    "VERSIONS",
     "AltairDeprecationWarning",
     "Optional",
     "PluginRegistry",
